function foo () {
  console.log( 'indented with spaces' );
}

export { foo as default };
